'''

Copyright (C) 2017-2019 Vanessa Sochat.

This Source Code Form is subject to the terms of the
Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

Written by Tom Schoonjans (Tom.Schoonjans@diamond.ac.uk)

'''

from sregistry.logger import bot
from sregistry.utils import ( parse_image_name, remove_uri, confirm_delete )

def remove(self, image, force=False):
    '''delete an image from an S3 bucket'''

    q = parse_image_name(remove_uri(image))

    uri = q['storage_uri']

    try:
        _object = self.bucket.Object(uri)
        _object.load() # this throws an exception if the object does not exist! -> if delete() fails no exception is thrown...

        if confirm_delete(force, uri) is True:
            _object.delete()
        else:
            bot.info("Delete cancelled.")
    except Exception as e:
        bot.error('Could not delete object {}: {}'.format(uri, str(e)))
        return None

    return image





'''

Copyright (C) 2017-2019 Vanessa Sochat.

This Source Code Form is subject to the terms of the
Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

'''

from sregistry.logger import bot

def main(args, parser, subparser):
    '''sharing an image means sending a remote share from an image you
       control to a contact, usually an email.
    '''
    from sregistry.main import get_client
    image = args.image

    # Detect any uri, and refresh client if necessary
    cli = get_client(image, quiet=args.quiet)
    cli.announce(args.command)

    # If the client doesn't have the command, exit
    if not hasattr(cli, 'share'):
        msg = "share is not implemented for %s. Why don't you add it?"
        bot.exit(msg % cli.client_name)

    cli.share(image, share_to=args.share_to)



'''

Copyright (C) 2017-2019 Vanessa Sochat.

This Source Code Form is subject to the terms of the
Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

'''

from sregistry.logger import bot

def main(args,parser,subparser):

    from sregistry.main import get_client
    image = args.query

    cli = get_client(image, quiet=args.quiet)

    # If the client doesn't have the command, exit
    if not hasattr(cli, 'inspect'):
        msg = "inspect is not implemented for %s. Why don't you add it?"
        bot.exit(msg % cli.client_name)

    cli.inspect(image)




'''

Copyright (C) 2016-2019 Vanessa Sochat.

This Source Code Form is subject to the terms of the
Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

'''

from sregistry.logger import bot
import sys
import pwd
import os


def main(args,parser,subparser):

    from sregistry.main import get_client
 
    image = args.image
    name = args.name

    # Customize client based on uri
    cli = get_client(image, quiet=args.quiet)
    cli.announce(args.command)

    # Does the user want to save the image?
    do_save = True
    if args.nocache is True or not hasattr(cli, 'storage'):
        do_save = False

    # If the client doesn't have the command, exit
    if not hasattr(cli, 'pull'):
        msg = "pull is not implemented for %s. Why don't you add it?"
        bot.exit(msg % cli.client_name)

    response = cli.pull(images=image,
                        file_name=name,
                        force=args.force,
                        save=do_save)



'''

Copyright (C) 2016-2019 Vanessa Sochat.

This Source Code Form is subject to the terms of the
Mozilla Public License, v. 2.0. If a copy of the MPL was not distributed
with this file, You can obtain one at http://mozilla.org/MPL/2.0/.

'''

from sregistry.logger import bot

def main(args, parser, subparser):

    from sregistry.main import get_client

    image = args.image

    cli = get_client(image, quiet=args.quiet)

    # If the client doesn't have the command, exit
    if not hasattr(cli, 'add'):
        bot.exit("add is only available when using the database")

    cli.add(image_path=image,
            image_uri=args.name,
            copy=args.copy)

